==> xlib-tronche-0.02.zip: xlib-tronche-0.02/z-dl/z-dl-cmd.sh <==
alias pushd="cd"
alias popd="cd .."

wget https://tronche.com/gui/x/xlib/

mkdir introduction/
pushd introduction/
 wget https://tronche.com/gui/x/xlib/introduction/
 wget https://tronche.com/gui/x/xlib/introduction/overview.html
 wget https://tronche.com/gui/x/xlib/introduction/errors.html
 wget https://tronche.com/gui/x/xlib/introduction/header.html
 wget https://tronche.com/gui/x/xlib/introduction/generic.html
 wget https://tronche.com/gui/x/xlib/introduction/naming.html
 wget https://tronche.com/gui/x/xlib/introduction/programming.html
 wget https://tronche.com/gui/x/xlib/introduction/character-set.html
 wget https://tronche.com/gui/x/xlib/introduction/formatting.html
popd # introduction/

mkdir display/
pushd display/
 wget https://tronche.com/gui/x/xlib/display/
 wget https://tronche.com/gui/x/xlib/display/opening.html
 wget https://tronche.com/gui/x/xlib/display/information.html
 wget https://tronche.com/gui/x/xlib/display/display-macros.html
 wget https://tronche.com/gui/x/xlib/display/image-format-macros.html
 wget https://tronche.com/gui/x/xlib/display/screen-information.html
 wget https://tronche.com/gui/x/xlib/display/XNoOp.html
 wget https://tronche.com/gui/x/xlib/display/XFree.html
 wget https://tronche.com/gui/x/xlib/display/closing.html
 wget https://tronche.com/gui/x/xlib/display/close-operation.html
 wget https://tronche.com/gui/x/xlib/display/XCloseDisplay.html
 wget https://tronche.com/gui/x/xlib/display/XSetCloseDownMode.html

 # https://tronche.com/gui/x/xlib/display/opening.html#Display
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DefaultScreen
 # https://tronche.com/gui/x/xlib/display/information.html#display

 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayWidth
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayHeight
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DisplayCells
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DisplayPlanes
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayWidthMM
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayHeightMM
popd # display/


mkdir window/
pushd window/
 wget https://tronche.com/gui/x/xlib/window/
 wget https://tronche.com/gui/x/xlib/window/create.html
 wget https://tronche.com/gui/x/xlib/window/destroy.html
 wget https://tronche.com/gui/x/xlib/window/map.html
 wget https://tronche.com/gui/x/xlib/window/unmap.html
 wget https://tronche.com/gui/x/xlib/window/configure.html
 wget https://tronche.com/gui/x/xlib/window/stacking-order.html
 wget https://tronche.com/gui/x/xlib/window/change-attributes.html
 wget https://tronche.com/gui/x/xlib/window/visual-types.html

 mkdir attributes/
 pushd attributes/
 wget https://tronche.com/gui/x/xlib/window/attributes/

  wget https://tronche.com/gui/x/xlib/window/attributes/gravity.html
  wget https://tronche.com/gui/x/xlib/window/attributes/event-and-do-not-propagate.html
  wget https://tronche.com/gui/x/xlib/window/attributes/override-redirect.html
  wget https://tronche.com/gui/x/xlib/window/attributes/cursor.html

  wget https://tronche.com/gui/x/xlib/window/attributes/background.html
  wget https://tronche.com/gui/x/xlib/window/attributes/border.html
  wget https://tronche.com/gui/x/xlib/window/attributes/backing-store.html
  wget https://tronche.com/gui/x/xlib/window/attributes/save-under.html
  wget https://tronche.com/gui/x/xlib/window/attributes/backing.html
  wget https://tronche.com/gui/x/xlib/window/attributes/colormap.html

 popd # attributes/

 wget https://tronche.com/gui/x/xlib/window/XRaiseWindow.html
 wget https://tronche.com/gui/x/xlib/window/XLowerWindow.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindows.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindowsUp.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindowsDown.html

 wget https://tronche.com/gui/x/xlib/window/XChangeWindowAttributes.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBackground.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBackgroundPixmap.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBorder.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBorderPixmap.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowColormap.html
 wget https://tronche.com/gui/x/xlib/window/XDefineCursor.html
 wget https://tronche.com/gui/x/xlib/window/XUndefineCursor.html

popd # window/

mkdir window-information/
pushd window-information/
 wget https://tronche.com/gui/x/xlib/window-information/

 wget https://tronche.com/gui/x/xlib/window-information/obtain.html
 wget https://tronche.com/gui/x/xlib/window-information/translate.html
 wget https://tronche.com/gui/x/xlib/window-information/properties-and-atoms.html
 wget https://tronche.com/gui/x/xlib/window-information/obtain-properties.html
 wget https://tronche.com/gui/x/xlib/window-information/selection.html

 wget https://tronche.com/gui/x/xlib/window-information/XQueryTree.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetWindowAttributes.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetGeometry.html

 wget https://tronche.com/gui/x/xlib/window-information/XTranslateCoordinates.html
 wget https://tronche.com/gui/x/xlib/window-information/XQueryPointer.html
 wget https://tronche.com/gui/x/xlib/window-information/XInternAtom.html

 wget https://tronche.com/gui/x/xlib/window-information/XGetAtomName.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetWindowProperty.html
 wget https://tronche.com/gui/x/xlib/window-information/XInternAtoms.html

 wget https://tronche.com/gui/x/xlib/window-information/XListProperties.html
 wget https://tronche.com/gui/x/xlib/window-information/XChangeProperty.html
 wget https://tronche.com/gui/x/xlib/window-information/XRotateWindowProperties.html
 wget https://tronche.com/gui/x/xlib/window-information/XDeleteProperty.html

popd # window-information/

mkdir pixmap-and-cursor/
pushd pixmap-and-cursor/

  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/
  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/pixmap.html
  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/cursor.html

popd # pixmap-and-cursor/

mkdir color/
pushd color/

 wget https://tronche.com/gui/x/xlib/color/
 wget https://tronche.com/gui/x/xlib/color/mapping-names-to-values.html
 wget https://tronche.com/gui/x/xlib/color/colormap.html
 wget https://tronche.com/gui/x/xlib/color/cell.html
 wget https://tronche.com/gui/x/xlib/color/modifying-and-querying-cells.html
 wget https://tronche.com/gui/x/xlib/color/converting-between-color-spaces.html

 wget https://tronche.com/gui/x/xlib/color/XAllocColor.html
 wget https://tronche.com/gui/x/xlib/color/XCreateColormap.html
 wget https://tronche.com/gui/x/xlib/color/XQueryColor.html
 wget https://tronche.com/gui/x/xlib/color/XQueryColors.html
 wget https://tronche.com/gui/x/xlib/color/XStoreColors.html

 mkdir strings/
 pushd strings/

  wget https://tronche.com/gui/x/xlib/color/strings/
  wget https://tronche.com/gui/x/xlib/color/strings/device-independent.html
  wget https://tronche.com/gui/x/xlib/color/strings/intensity.html
  wget https://tronche.com/gui/x/xlib/color/strings/rgb.html

 popd # strings/

popd # color/

mkdir GC/
pushd GC/
 wget https://tronche.com/gui/x/xlib/GC/

 wget https://tronche.com/gui/x/xlib/GC/manipulating.html

 mkdir convenience-functions/
 pushd convenience-functions/
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/foreground-etc.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/line-dashes.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/fill-style-and-rule.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/fill-tile-and-stipple.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/font.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/clip-region.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/arc-subwindow-etc.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetBackground.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetFunction.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetPlaneMask.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetForeground.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetLineAttributes.html

 popd # convenience-functions/

 wget https://tronche.com/gui/x/xlib/GC/XGContextFromGC.html

popd # GC/

mkdir graphics/
pushd graphics/

 wget https://tronche.com/gui/x/xlib/graphics/

 mkdir drawing-text/
 pushd drawing-text/
  wget https://tronche.com/gui/x/xlib/graphics/drawing-text/XDrawText.html
  wget https://tronche.com/gui/x/xlib/graphics/drawing-text/XDrawText16.html
 popd # drawing-text/

 mkdir drawing/
 pushd drawing/
  wget https://tronche.com/gui/x/xlib/graphics/drawing/
 popd # drawing/

 mkdir filling-areas/
 pushd filling-areas/
  wget https://tronche.com/gui/x/xlib/graphics/filling-areas/
 popd # filling-areas/

 mkdir font-metrics/
 pushd font-metrics/
  wget https://tronche.com/gui/x/xlib/graphics/font-metrics/
 popd # font-metrics/

popd # graphics/

mkdir ICC/
pushd ICC/

 wget https://tronche.com/gui/x/xlib/ICC/

 mkdir client-to-window-manager/
 pushd client-to-window-manager/
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/

  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/manipulating-top-level-windows.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/converting-string-lists.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/text.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-name.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-icon-name.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-hints.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-normal-hints.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-class.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-transient-for.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-protocols.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-colormap-windows.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-icon-size.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/using-convenience-functions.html

  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XIconifyWindow.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XWithdrawWindow.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XReconfigureWMWindow.html

 popd # client-to-window-manager/
popd # ICC/

==> xlib-tronche-0.03.zip: xlib-tronche-0.03/z-dl/z-dl-cmd.sh <==
alias pushd="cd"
alias popd="cd .."

wget https://tronche.com/gui/x/xlib/

mkdir introduction/
pushd introduction/
 wget https://tronche.com/gui/x/xlib/introduction/
 wget https://tronche.com/gui/x/xlib/introduction/overview.html
 wget https://tronche.com/gui/x/xlib/introduction/errors.html
 wget https://tronche.com/gui/x/xlib/introduction/header.html
 wget https://tronche.com/gui/x/xlib/introduction/generic.html
 wget https://tronche.com/gui/x/xlib/introduction/naming.html
 wget https://tronche.com/gui/x/xlib/introduction/programming.html
 wget https://tronche.com/gui/x/xlib/introduction/character-set.html
 wget https://tronche.com/gui/x/xlib/introduction/formatting.html
popd # introduction/

mkdir display/
pushd display/
 wget https://tronche.com/gui/x/xlib/display/
 wget https://tronche.com/gui/x/xlib/display/opening.html
 wget https://tronche.com/gui/x/xlib/display/information.html
 wget https://tronche.com/gui/x/xlib/display/display-macros.html
 wget https://tronche.com/gui/x/xlib/display/image-format-macros.html
 wget https://tronche.com/gui/x/xlib/display/screen-information.html
 wget https://tronche.com/gui/x/xlib/display/XNoOp.html
 wget https://tronche.com/gui/x/xlib/display/XFree.html
 wget https://tronche.com/gui/x/xlib/display/closing.html
 wget https://tronche.com/gui/x/xlib/display/close-operation.html
 wget https://tronche.com/gui/x/xlib/display/XCloseDisplay.html
 wget https://tronche.com/gui/x/xlib/display/XSetCloseDownMode.html

 # https://tronche.com/gui/x/xlib/display/opening.html#Display
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DefaultScreen
 # https://tronche.com/gui/x/xlib/display/information.html#display

 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayWidth
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayHeight
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DisplayCells
 # https://tronche.com/gui/x/xlib/display/display-macros.html#DisplayPlanes
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayWidthMM
 # https://tronche.com/gui/x/xlib/display/image-format-macros.html#DisplayHeightMM
popd # display/


mkdir window/
pushd window/
 wget https://tronche.com/gui/x/xlib/window/
 wget https://tronche.com/gui/x/xlib/window/create.html
 wget https://tronche.com/gui/x/xlib/window/destroy.html
 wget https://tronche.com/gui/x/xlib/window/map.html
 wget https://tronche.com/gui/x/xlib/window/unmap.html
 wget https://tronche.com/gui/x/xlib/window/configure.html
 wget https://tronche.com/gui/x/xlib/window/stacking-order.html
 wget https://tronche.com/gui/x/xlib/window/change-attributes.html
 wget https://tronche.com/gui/x/xlib/window/visual-types.html

 mkdir attributes/
 pushd attributes/
 wget https://tronche.com/gui/x/xlib/window/attributes/

  wget https://tronche.com/gui/x/xlib/window/attributes/gravity.html
  wget https://tronche.com/gui/x/xlib/window/attributes/event-and-do-not-propagate.html
  wget https://tronche.com/gui/x/xlib/window/attributes/override-redirect.html
  wget https://tronche.com/gui/x/xlib/window/attributes/cursor.html

  wget https://tronche.com/gui/x/xlib/window/attributes/background.html
  wget https://tronche.com/gui/x/xlib/window/attributes/border.html
  wget https://tronche.com/gui/x/xlib/window/attributes/backing-store.html
  wget https://tronche.com/gui/x/xlib/window/attributes/save-under.html
  wget https://tronche.com/gui/x/xlib/window/attributes/backing.html
  wget https://tronche.com/gui/x/xlib/window/attributes/colormap.html

 popd # attributes/

 wget https://tronche.com/gui/x/xlib/window/XRaiseWindow.html
 wget https://tronche.com/gui/x/xlib/window/XLowerWindow.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindows.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindowsUp.html
 wget https://tronche.com/gui/x/xlib/window/XCirculateSubwindowsDown.html

 wget https://tronche.com/gui/x/xlib/window/XChangeWindowAttributes.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBackground.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBackgroundPixmap.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBorder.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowBorderPixmap.html
 wget https://tronche.com/gui/x/xlib/window/XSetWindowColormap.html
 wget https://tronche.com/gui/x/xlib/window/XDefineCursor.html
 wget https://tronche.com/gui/x/xlib/window/XUndefineCursor.html

popd # window/

mkdir window-information/
pushd window-information/
 wget https://tronche.com/gui/x/xlib/window-information/

 wget https://tronche.com/gui/x/xlib/window-information/obtain.html
 wget https://tronche.com/gui/x/xlib/window-information/translate.html
 wget https://tronche.com/gui/x/xlib/window-information/properties-and-atoms.html
 wget https://tronche.com/gui/x/xlib/window-information/obtain-properties.html
 wget https://tronche.com/gui/x/xlib/window-information/selection.html

 wget https://tronche.com/gui/x/xlib/window-information/XQueryTree.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetWindowAttributes.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetGeometry.html

 wget https://tronche.com/gui/x/xlib/window-information/XTranslateCoordinates.html
 wget https://tronche.com/gui/x/xlib/window-information/XQueryPointer.html
 wget https://tronche.com/gui/x/xlib/window-information/XInternAtom.html

 wget https://tronche.com/gui/x/xlib/window-information/XGetAtomName.html
 wget https://tronche.com/gui/x/xlib/window-information/XGetWindowProperty.html
 wget https://tronche.com/gui/x/xlib/window-information/XInternAtoms.html

 wget https://tronche.com/gui/x/xlib/window-information/XListProperties.html
 wget https://tronche.com/gui/x/xlib/window-information/XChangeProperty.html
 wget https://tronche.com/gui/x/xlib/window-information/XRotateWindowProperties.html
 wget https://tronche.com/gui/x/xlib/window-information/XDeleteProperty.html

popd # window-information/

mkdir pixmap-and-cursor/
pushd pixmap-and-cursor/

  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/
  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/pixmap.html
  wget https://tronche.com/gui/x/xlib/pixmap-and-cursor/cursor.html

popd # pixmap-and-cursor/

mkdir color/
pushd color/

 wget https://tronche.com/gui/x/xlib/color/
 wget https://tronche.com/gui/x/xlib/color/mapping-names-to-values.html
 wget https://tronche.com/gui/x/xlib/color/colormap.html
 wget https://tronche.com/gui/x/xlib/color/cell.html
 wget https://tronche.com/gui/x/xlib/color/modifying-and-querying-cells.html
 wget https://tronche.com/gui/x/xlib/color/converting-between-color-spaces.html

 wget https://tronche.com/gui/x/xlib/color/structures.html

 wget https://tronche.com/gui/x/xlib/color/XAllocColor.html
 wget https://tronche.com/gui/x/xlib/color/XCreateColormap.html
 wget https://tronche.com/gui/x/xlib/color/XQueryColor.html
 wget https://tronche.com/gui/x/xlib/color/XQueryColors.html
 wget https://tronche.com/gui/x/xlib/color/XStoreColors.html

 mkdir strings/
 pushd strings/

  wget https://tronche.com/gui/x/xlib/color/strings/
  wget https://tronche.com/gui/x/xlib/color/strings/device-independent.html
  wget https://tronche.com/gui/x/xlib/color/strings/intensity.html
  wget https://tronche.com/gui/x/xlib/color/strings/rgb.html

 popd # strings/

 mkdir CCC/
 pushd CCC/

  wget https://tronche.com/gui/x/xlib/color/CCC/

 popd # CCC/

popd # color/

mkdir GC/
pushd GC/
 wget https://tronche.com/gui/x/xlib/GC/

 wget https://tronche.com/gui/x/xlib/GC/manipulating.html

 mkdir convenience-functions/
 pushd convenience-functions/
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/foreground-etc.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/line-dashes.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/fill-style-and-rule.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/fill-tile-and-stipple.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/font.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/clip-region.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/arc-subwindow-etc.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetBackground.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetFunction.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetPlaneMask.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetForeground.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetLineAttributes.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetDashes.html
  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XQueryBestSize.html

  wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetClipRectangles.html

 popd # convenience-functions/

 wget https://tronche.com/gui/x/xlib/GC/XGContextFromGC.html

popd # GC/

mkdir graphics/
pushd graphics/

 wget https://tronche.com/gui/x/xlib/graphics/
 wget https://tronche.com/gui/x/xlib/graphics/XCopyArea.html
 wget https://tronche.com/gui/x/xlib/graphics/XCopyPlane.html

 mkdir drawing-text/
 pushd drawing-text/
  wget https://tronche.com/gui/x/xlib/graphics/drawing-text/XDrawText.html
  wget https://tronche.com/gui/x/xlib/graphics/drawing-text/XDrawText16.html
 popd # drawing-text/

 mkdir drawing/
 pushd drawing/
  wget https://tronche.com/gui/x/xlib/graphics/drawing/
  wget https://tronche.com/gui/x/xlib/graphics/drawing/XDrawRectangle.html
  wget https://tronche.com/gui/x/xlib/graphics/drawing/XDrawLine.html
  wget https://tronche.com/gui/x/xlib/graphics/drawing/XDrawArc.html
  wget https://tronche.com/gui/x/xlib/graphics/drawing/XDrawSegments.html
 popd # drawing/

 mkdir filling-areas/
 pushd filling-areas/
  wget https://tronche.com/gui/x/xlib/graphics/filling-areas/
  wget https://tronche.com/gui/x/xlib/graphics/filling-areas/XFillArcs.html
 popd # filling-areas/

 mkdir font-metrics/
 pushd font-metrics/
  wget https://tronche.com/gui/x/xlib/graphics/font-metrics/
 popd # font-metrics/

popd # graphics/

mkdir input/
pushd input/

 wget https://tronche.com/gui/x/xlib/input/

 wget https://tronche.com/gui/x/xlib/input/pointer-grabbing.html
 wget https://tronche.com/gui/x/xlib/input/keyboard-grabbing.html
 wget https://tronche.com/gui/x/xlib/input/moving-pointer.html
 wget https://tronche.com/gui/x/xlib/input/controlling-focus.html
 wget https://tronche.com/gui/x/xlib/input/keyboard-and-pointer-settings.html
 wget https://tronche.com/gui/x/xlib/input/keyboard-encoding.html

popd # input/

mkdir ICC/
pushd ICC/

 wget https://tronche.com/gui/x/xlib/ICC/

 mkdir client-to-window-manager/
 pushd client-to-window-manager/
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/

  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/manipulating-top-level-windows.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/converting-string-lists.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/text.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-name.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-icon-name.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-hints.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-normal-hints.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-class.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-transient-for.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-protocols.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-colormap-windows.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/wm-icon-size.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/using-convenience-functions.html

  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XIconifyWindow.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XWithdrawWindow.html
  wget https://tronche.com/gui/x/xlib/ICC/client-to-window-manager/XReconfigureWMWindow.html

 popd # client-to-window-manager/
popd # ICC/

 wget https://tronche.com/gui/x/xlib/GC/convenience-functions/XSetDashes
